# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/placement_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import placement_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/compute/v1/placement_group_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a-yandex/cloud/compute/v1/placement_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x18GetPlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"\xb4\x01\n\x1aListPlacementGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n\x1bListPlacementGroupsResponse\x12\x41\n\x10placement_groups\x18\x01 \x03(\x0b\x32\'.yandex.cloud.compute.v1.PlacementGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa4\x03\n\x1b\x43reatePlacementGroupRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12P\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry\x12U\n\x19spread_placement_strategy\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.compute.v1.SpreadPlacementStrategyH\x00\x12[\n\x1cpartition_placement_strategy\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.PartitionPlacementStrategyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1a\n\x12placement_strategy\x12\x04\xc0\xc1\x31\x01\":\n\x1c\x43reatePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"\x8e\x02\n\x1bUpdatePlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12P\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1cUpdatePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"9\n\x1b\x44\x65letePlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\":\n\x1c\x44\x65letePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"g\n\"ListPlacementGroupInstancesRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"t\n#ListPlacementGroupInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"h\n#ListPlacementGroupOperationsRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n$ListPlacementGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xa0\x10\n\x15PlacementGroupService\x12\x9b\x01\n\x03Get\x12\x31.yandex.cloud.compute.v1.GetPlacementGroupRequest\x1a\'.yandex.cloud.compute.v1.PlacementGroup\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/compute/v1/placementGroups/{placement_group_id}\x12\x96\x01\n\x04List\x12\x33.yandex.cloud.compute.v1.ListPlacementGroupsRequest\x1a\x34.yandex.cloud.compute.v1.ListPlacementGroupsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/placementGroups\x12\xbb\x01\n\x06\x43reate\x12\x34.yandex.cloud.compute.v1.CreatePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*.\n\x1c\x43reatePlacementGroupMetadata\x12\x0ePlacementGroup\x82\xd3\xe4\x93\x02 \"\x1b/compute/v1/placementGroups:\x01*\x12\xd0\x01\n\x06Update\x12\x34.yandex.cloud.compute.v1.UpdatePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*.\n\x1cUpdatePlacementGroupMetadata\x12\x0ePlacementGroup\x82\xd3\xe4\x93\x02\x35\x32\x30/compute/v1/placementGroups/{placement_group_id}:\x01*\x12\xd4\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.compute.v1.DeletePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*5\n\x1c\x44\x65letePlacementGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x32*0/compute/v1/placementGroups/{placement_group_id}\x12\xce\x01\n\rListInstances\x12;.yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest\x1a<.yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse\"B\x82\xd3\xe4\x93\x02<\x12:/compute/v1/placementGroups/{placement_group_id}/instances\x12\xd2\x01\n\x0eListOperations\x12<.yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest\x1a=.yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/compute/v1/placementGroups/{placement_group_id}/operations\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</compute/v1/placementGroups/{resource_id}:listAccessBindings\x12\xfa\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02@\";/compute/v1/placementGroups/{resource_id}:setAccessBindings:\x01*\x12\x86\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x98\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x43\">/compute/v1/placementGroups/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.placement_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['order_by']._options = None
  _LISTPLACEMENTGROUPSREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _CREATEPLACEMENTGROUPREQUEST_LABELSENTRY._options = None
  _CREATEPLACEMENTGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']._options = None
  _CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']._serialized_options = b'\300\3011\001'
  _UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY._options = None
  _UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _PLACEMENTGROUPSERVICE.methods_by_name['Get']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0022\0220/compute/v1/placementGroups/{placement_group_id}'
  _PLACEMENTGROUPSERVICE.methods_by_name['List']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\035\022\033/compute/v1/placementGroups'
  _PLACEMENTGROUPSERVICE.methods_by_name['Create']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*.\n\034CreatePlacementGroupMetadata\022\016PlacementGroup\202\323\344\223\002 \"\033/compute/v1/placementGroups:\001*'
  _PLACEMENTGROUPSERVICE.methods_by_name['Update']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*.\n\034UpdatePlacementGroupMetadata\022\016PlacementGroup\202\323\344\223\002520/compute/v1/placementGroups/{placement_group_id}:\001*'
  _PLACEMENTGROUPSERVICE.methods_by_name['Delete']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*5\n\034DeletePlacementGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0022*0/compute/v1/placementGroups/{placement_group_id}'
  _PLACEMENTGROUPSERVICE.methods_by_name['ListInstances']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['ListInstances']._serialized_options = b'\202\323\344\223\002<\022:/compute/v1/placementGroups/{placement_group_id}/instances'
  _PLACEMENTGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002=\022;/compute/v1/placementGroups/{placement_group_id}/operations'
  _PLACEMENTGROUPSERVICE.methods_by_name['ListAccessBindings']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002>\022</compute/v1/placementGroups/{resource_id}:listAccessBindings'
  _PLACEMENTGROUPSERVICE.methods_by_name['SetAccessBindings']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002@\";/compute/v1/placementGroups/{resource_id}:setAccessBindings:\001*'
  _PLACEMENTGROUPSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _PLACEMENTGROUPSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002C\">/compute/v1/placementGroups/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETPLACEMENTGROUPREQUEST']._serialized_start=372
  _globals['_GETPLACEMENTGROUPREQUEST']._serialized_end=426
  _globals['_LISTPLACEMENTGROUPSREQUEST']._serialized_start=429
  _globals['_LISTPLACEMENTGROUPSREQUEST']._serialized_end=609
  _globals['_LISTPLACEMENTGROUPSRESPONSE']._serialized_start=611
  _globals['_LISTPLACEMENTGROUPSRESPONSE']._serialized_end=732
  _globals['_CREATEPLACEMENTGROUPREQUEST']._serialized_start=735
  _globals['_CREATEPLACEMENTGROUPREQUEST']._serialized_end=1155
  _globals['_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_start=1082
  _globals['_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_end=1127
  _globals['_CREATEPLACEMENTGROUPMETADATA']._serialized_start=1157
  _globals['_CREATEPLACEMENTGROUPMETADATA']._serialized_end=1215
  _globals['_UPDATEPLACEMENTGROUPREQUEST']._serialized_start=1218
  _globals['_UPDATEPLACEMENTGROUPREQUEST']._serialized_end=1488
  _globals['_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_start=1082
  _globals['_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY']._serialized_end=1127
  _globals['_UPDATEPLACEMENTGROUPMETADATA']._serialized_start=1490
  _globals['_UPDATEPLACEMENTGROUPMETADATA']._serialized_end=1548
  _globals['_DELETEPLACEMENTGROUPREQUEST']._serialized_start=1550
  _globals['_DELETEPLACEMENTGROUPREQUEST']._serialized_end=1607
  _globals['_DELETEPLACEMENTGROUPMETADATA']._serialized_start=1609
  _globals['_DELETEPLACEMENTGROUPMETADATA']._serialized_end=1667
  _globals['_LISTPLACEMENTGROUPINSTANCESREQUEST']._serialized_start=1669
  _globals['_LISTPLACEMENTGROUPINSTANCESREQUEST']._serialized_end=1772
  _globals['_LISTPLACEMENTGROUPINSTANCESRESPONSE']._serialized_start=1774
  _globals['_LISTPLACEMENTGROUPINSTANCESRESPONSE']._serialized_end=1890
  _globals['_LISTPLACEMENTGROUPOPERATIONSREQUEST']._serialized_start=1892
  _globals['_LISTPLACEMENTGROUPOPERATIONSREQUEST']._serialized_end=1996
  _globals['_LISTPLACEMENTGROUPOPERATIONSRESPONSE']._serialized_start=1998
  _globals['_LISTPLACEMENTGROUPOPERATIONSRESPONSE']._serialized_end=2116
  _globals['_PLACEMENTGROUPSERVICE']._serialized_start=2119
  _globals['_PLACEMENTGROUPSERVICE']._serialized_end=4199
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.k8s.v1.maintenance_pb2
import yandex.cloud.k8s.v1.node_pb2
import yandex.cloud.k8s.v1.version_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class NodeGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NodeGroup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: NodeGroup._Status.ValueType  # 0
        PROVISIONING: NodeGroup._Status.ValueType  # 1
        """Node group is waiting for resources to be allocated."""
        RUNNING: NodeGroup._Status.ValueType  # 2
        """Node group is running."""
        RECONCILING: NodeGroup._Status.ValueType  # 3
        """Node group is waiting for some work to be done, such as upgrading node software."""
        STOPPING: NodeGroup._Status.ValueType  # 4
        """Node group is being stopped."""
        STOPPED: NodeGroup._Status.ValueType  # 5
        """Node group stopped."""
        DELETING: NodeGroup._Status.ValueType  # 6
        """Node group is being deleted."""
        STARTING: NodeGroup._Status.ValueType  # 7
        """Node group is being started."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: NodeGroup.Status.ValueType  # 0
    PROVISIONING: NodeGroup.Status.ValueType  # 1
    """Node group is waiting for resources to be allocated."""
    RUNNING: NodeGroup.Status.ValueType  # 2
    """Node group is running."""
    RECONCILING: NodeGroup.Status.ValueType  # 3
    """Node group is waiting for some work to be done, such as upgrading node software."""
    STOPPING: NodeGroup.Status.ValueType  # 4
    """Node group is being stopped."""
    STOPPED: NodeGroup.Status.ValueType  # 5
    """Node group stopped."""
    DELETING: NodeGroup.Status.ValueType  # 6
    """Node group is being deleted."""
    STARTING: NodeGroup.Status.ValueType  # 7
    """Node group is being started."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NodeLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NODE_TEMPLATE_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    DEPLOY_POLICY_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_ID_FIELD_NUMBER: builtins.int
    NODE_VERSION_FIELD_NUMBER: builtins.int
    VERSION_INFO_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    ALLOWED_UNSAFE_SYSCTLS_FIELD_NUMBER: builtins.int
    NODE_TAINTS_FIELD_NUMBER: builtins.int
    NODE_LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the node group."""
    cluster_id: builtins.str
    """ID of the cluster that the node group belongs to."""
    name: builtins.str
    """Name of the node group.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the node group. 0-256 characters long."""
    status: global___NodeGroup.Status.ValueType
    """Status of the node group."""
    instance_group_id: builtins.str
    """ID of the managed instance group associated with this node group."""
    node_version: builtins.str
    """Version of Kubernetes components that runs on the nodes.
    Deprecated. Use version_info.current_version.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def node_template(self) -> yandex.cloud.k8s.v1.node_pb2.NodeTemplate:
        """Node template that specifies parameters of the compute instances for the node group."""

    @property
    def scale_policy(self) -> global___ScalePolicy:
        """Scale policy of the node group.  For more information, see [Scaling policy](/docs/compute/concepts/instance-groups/policies#scale-policy)."""

    @property
    def allocation_policy(self) -> global___NodeGroupAllocationPolicy:
        """Allocation policy by which resources for node group are allocated to zones and regions."""

    @property
    def deploy_policy(self) -> global___DeployPolicy:
        """Deploy policy according to which the updates are rolled out."""

    @property
    def version_info(self) -> yandex.cloud.k8s.v1.version_pb2.VersionInfo:
        """Detailed information about the Kubernetes version that is running on the node."""

    @property
    def maintenance_policy(self) -> global___NodeGroupMaintenancePolicy:
        """Maintenance policy of the node group."""

    @property
    def allowed_unsafe_sysctls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Support for unsafe sysctl parameters. For more details see [documentation](https://kubernetes.io/docs/tasks/administer-cluster/sysctl-cluster/)."""

    @property
    def node_taints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_pb2.Taint]:
        """Taints that are applied to the nodes of the node group at creation time."""

    @property
    def node_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels that are assigned to the nodes of the node group at creation time."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___NodeGroup.Status.ValueType = ...,
        node_template: yandex.cloud.k8s.v1.node_pb2.NodeTemplate | None = ...,
        scale_policy: global___ScalePolicy | None = ...,
        allocation_policy: global___NodeGroupAllocationPolicy | None = ...,
        deploy_policy: global___DeployPolicy | None = ...,
        instance_group_id: builtins.str = ...,
        node_version: builtins.str = ...,
        version_info: yandex.cloud.k8s.v1.version_pb2.VersionInfo | None = ...,
        maintenance_policy: global___NodeGroupMaintenancePolicy | None = ...,
        allowed_unsafe_sysctls: collections.abc.Iterable[builtins.str] | None = ...,
        node_taints: collections.abc.Iterable[yandex.cloud.k8s.v1.node_pb2.Taint] | None = ...,
        node_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "created_at", b"created_at", "deploy_policy", b"deploy_policy", "maintenance_policy", b"maintenance_policy", "node_template", b"node_template", "scale_policy", b"scale_policy", "version_info", b"version_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "allowed_unsafe_sysctls", b"allowed_unsafe_sysctls", "cluster_id", b"cluster_id", "created_at", b"created_at", "deploy_policy", b"deploy_policy", "description", b"description", "id", b"id", "instance_group_id", b"instance_group_id", "labels", b"labels", "maintenance_policy", b"maintenance_policy", "name", b"name", "node_labels", b"node_labels", "node_taints", b"node_taints", "node_template", b"node_template", "node_version", b"node_version", "scale_policy", b"scale_policy", "status", b"status", "version_info", b"version_info"]) -> None: ...

global___NodeGroup = NodeGroup

@typing.final
class ScalePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FixedScale(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        """Number of nodes in the node group."""
        def __init__(
            self,
            *,
            size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

    @typing.final
    class AutoScale(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MIN_SIZE_FIELD_NUMBER: builtins.int
        MAX_SIZE_FIELD_NUMBER: builtins.int
        INITIAL_SIZE_FIELD_NUMBER: builtins.int
        min_size: builtins.int
        """Minimum number of nodes in the node group."""
        max_size: builtins.int
        """Maximum number of nodes in the node group."""
        initial_size: builtins.int
        """Initial number of nodes in the node group."""
        def __init__(
            self,
            *,
            min_size: builtins.int = ...,
            max_size: builtins.int = ...,
            initial_size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["initial_size", b"initial_size", "max_size", b"max_size", "min_size", b"min_size"]) -> None: ...

    FIXED_SCALE_FIELD_NUMBER: builtins.int
    AUTO_SCALE_FIELD_NUMBER: builtins.int
    @property
    def fixed_scale(self) -> global___ScalePolicy.FixedScale:
        """Fixed scale policy of the node group."""

    @property
    def auto_scale(self) -> global___ScalePolicy.AutoScale:
        """Auto scale policy of the node group."""

    def __init__(
        self,
        *,
        fixed_scale: global___ScalePolicy.FixedScale | None = ...,
        auto_scale: global___ScalePolicy.AutoScale | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["scale_type", b"scale_type"]) -> typing.Literal["fixed_scale", "auto_scale"] | None: ...

global___ScalePolicy = ScalePolicy

@typing.final
class NodeGroupAllocationPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATIONS_FIELD_NUMBER: builtins.int
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NodeGroupLocation]:
        """List of locations where resources for the node group will be allocated."""

    def __init__(
        self,
        *,
        locations: collections.abc.Iterable[global___NodeGroupLocation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["locations", b"locations"]) -> None: ...

global___NodeGroupAllocationPolicy = NodeGroupAllocationPolicy

@typing.final
class NodeGroupLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the nodes may reside."""
    subnet_id: builtins.str
    """ID of the subnet. If a network chosen for the Kubernetes cluster has only one subnet in the specified zone, subnet ID may be omitted."""
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___NodeGroupLocation = NodeGroupLocation

@typing.final
class NodeGroupMaintenancePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_UPGRADE_FIELD_NUMBER: builtins.int
    AUTO_REPAIR_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    auto_upgrade: builtins.bool
    """If set to true, automatic updates are installed in the specified period of time with no interaction from the user.
    If set to false, automatic upgrades are disabled.
    """
    auto_repair: builtins.bool
    """If set to true, automatic repairs are enabled. Default value is false."""
    @property
    def maintenance_window(self) -> yandex.cloud.k8s.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window settings. Update will start at the specified time and last no more than the specified duration.
        The time is set in UTC.
        """

    def __init__(
        self,
        *,
        auto_upgrade: builtins.bool = ...,
        auto_repair: builtins.bool = ...,
        maintenance_window: yandex.cloud.k8s.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["maintenance_window", b"maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_repair", b"auto_repair", "auto_upgrade", b"auto_upgrade", "maintenance_window", b"maintenance_window"]) -> None: ...

global___NodeGroupMaintenancePolicy = NodeGroupMaintenancePolicy

@typing.final
class DeployPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    MAX_EXPANSION_FIELD_NUMBER: builtins.int
    max_unavailable: builtins.int
    """The maximum number of running instances that can be taken offline (i.e.,
    stopped or deleted) at the same time during the update process.
    If [max_expansion] is not specified or set to zero, [max_unavailable] must
    be set to a non-zero value.
    """
    max_expansion: builtins.int
    """The maximum number of instances that can be temporarily allocated above
    the group's target size during the update process.
    If [max_unavailable] is not specified or set to zero, [max_expansion] must
    be set to a non-zero value.
    """
    def __init__(
        self,
        *,
        max_unavailable: builtins.int = ...,
        max_expansion: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max_expansion", b"max_expansion", "max_unavailable", b"max_unavailable"]) -> None: ...

global___DeployPolicy = DeployPolicy



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.dataproc.manager.v1 import job_service_pb2 as yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListActive = channel.unary_unary(
                '/yandex.cloud.dataproc.manager.v1.JobService/ListActive',
                request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
                )
        self.UpdateStatus = channel.unary_unary(
                '/yandex.cloud.dataproc.manager.v1.JobService/UpdateStatus',
                request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.FromString,
                )
        self.ListSupportActive = channel.unary_unary(
                '/yandex.cloud.dataproc.manager.v1.JobService/ListSupportActive',
                request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListSupportJobsResponse.FromString,
                )
        self.UpdateSupportStatus = channel.unary_unary(
                '/yandex.cloud.dataproc.manager.v1.JobService/UpdateSupportStatus',
                request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateSupportJobStatusRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.FromString,
                )
        self.SaveSupportLog = channel.unary_unary(
                '/yandex.cloud.dataproc.manager.v1.JobService/SaveSupportLog',
                request_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.SaveSupportJobLogRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.SaveSupportJobLogResponse.FromString,
                )


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListActive(self, request, context):
        """Retrieves a list of jobs for Data Proc cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateStatus(self, request, context):
        """Currently used to update Job status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSupportActive(self, request, context):
        """Retrieves a list of support jobs for Data Proc cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSupportStatus(self, request, context):
        """Currently used to update support job status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveSupportLog(self, request, context):
        """Save support job output.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListActive': grpc.unary_unary_rpc_method_handler(
                    servicer.ListActive,
                    request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.SerializeToString,
            ),
            'UpdateStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateStatus,
                    request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.SerializeToString,
            ),
            'ListSupportActive': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSupportActive,
                    request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListSupportJobsResponse.SerializeToString,
            ),
            'UpdateSupportStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSupportStatus,
                    request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateSupportJobStatusRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.SerializeToString,
            ),
            'SaveSupportLog': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveSupportLog,
                    request_deserializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.SaveSupportJobLogRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.SaveSupportJobLogResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.dataproc.manager.v1.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListActive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dataproc.manager.v1.JobService/ListActive',
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dataproc.manager.v1.JobService/UpdateStatus',
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusRequest.SerializeToString,
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSupportActive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dataproc.manager.v1.JobService/ListSupportActive',
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListJobsRequest.SerializeToString,
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.ListSupportJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSupportStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dataproc.manager.v1.JobService/UpdateSupportStatus',
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateSupportJobStatusRequest.SerializeToString,
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.UpdateJobStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveSupportLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.dataproc.manager.v1.JobService/SaveSupportLog',
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.SaveSupportJobLogRequest.SerializeToString,
            yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__service__pb2.SaveSupportJobLogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
